@@ -25,20 +25,31 @@ ENAplot = R6::R6Class("ENAplot",
 
         title = "ENA Plot",
 
-        dimension.labels = c("X","Y"),
+        dimension.labels = c("",""),
 
         font.size = 14,
         font.color = "#000000",
         font.family = "Arial",
-        scale.to = c("network", "points"),
+        scale.to = "network",
         ...
       ) {
-        scale.to = match.arg(scale.to);
+
+        if (is(enaset, "ENAset")) {
+          warning(paste0("Usage of ENAset objects will be deprecated ",
+            "and potentially removed altogether in future versions."))
+
+          enaset <- ena.set(enaset);
+        }
+
+        code.cols = !colnames(enaset$line.weights) %in% colnames(enaset$meta.data)
 
         args = list(...);
         if(!is.null(args$multiplier)) {
           private$multiplier = args$multiplier
         }
+        if(!is.null(args$point.size)) {
+          self$point$size = args$point.size
+        }
         self$enaset <- enaset;
 
         private$title <- title;
@@ -56,21 +67,36 @@ ENAplot = R6::R6Class("ENAplot",
           type ="scatter"
         );
 
+        if (is.list(scale.to)) {
+          max.axis = max(abs(as.matrix(enaset$points)))*1.2
+          if(is.null(scale.to$x)) {
+            axis.range.x = c(-max.axis, max.axis)
+          } else {
+            axis.range.x = scale.to$x
+          }
+          if(is.null(scale.to$y)) {
+            axis.range.y = c(-max.axis, max.axis)
+          } else {
+            axis.range.y = scale.to$y
+          }
+        } else {
+          if(scale.to == "points") {
+            max.axis = max(abs(as.matrix(enaset$points)))*1.2
+          } else if (is.numeric(scale.to)) {
+            max.axis = tail(scale.to, 1)
+          } else {
+            max.axis = max(abs(as.matrix(enaset$rotation$nodes)))*1.2;
+          }
+          axis.range.x = axis.range.y = c(-max.axis, max.axis)
+        }
 
-        # browser()
-        # max.axis = max(abs(points))*1.2;
-        max.axis = max(abs(enaset$node.positions))*1.2;
-        if(scale.to == "points") {
-          max.axis = max(abs(enaset$points.rotated))*1.2;
-        };
-        # network.graph.axis <- list(title = "", showgrid = T, showticklabels = T, zeroline = T, range=c(-max.axis,max.axis));
         graph.axis <- list(
           titlefont = private$font,
           showgrid = F,
           zeroline = T,
           showticklabels = T,
-          showgrid = T,
-          range=c(-max.axis,max.axis)
+          showgrid = T
+          # range=c(-max.axis,max.axis)
         );
         if(!is.null(args$ticks)) {
           graph.axis$showticklabels = T;
@@ -80,12 +106,10 @@ ENAplot = R6::R6Class("ENAplot",
         }
         self$axes$x = graph.axis
         self$axes$x$title = dimension.labels[1];
+        self$axes$x$range = axis.range.x
         self$axes$y = graph.axis
         self$axes$y$title = dimension.labels[2];
-
-        # self$axes$max = max.axis;
-        # self$axes$objects$x = graph.axis.x;
-        # self$axes$objects$y = graph.axis.y;
+        self$axes$y$range = axis.range.y
 
         self$plot = plotly::layout(
           self$plot,
@@ -111,6 +135,15 @@ ENAplot = R6::R6Class("ENAplot",
       axes = list(
         x = NULL, y = NULL
       ),
+      point = list(
+        size = 5
+      ),
+      palette = c("#386CB0", "#F0027F", "#7FC97F", "#BEAED4",
+                  "#FDC086","#FFFF99", "#BF5B17"),
+      plotted = list(
+        points = list(), networks = list(),
+        trajectories = list(), means = list()
+      ),
     ####
     ## END: Public Properties
     ####
