@@ -31,14 +31,14 @@ ENAset = R6::R6Class("ENAset",
        enadata,
        dimensions = 2,
 
-       norm.by = sphere_norm_c,
+       norm.by = fun_sphere_norm,
 
-       rotation.by = ena.svd,
+       rotation.by = ena.svd.R6,
        rotation.params = NULL,
        rotation.set = NULL,
 
        #center.data = center_data_c,    ### made local to run
-       node.position.method = lws.positions.sq,
+       node.position.method = lws.positions.sq.R6,
        endpoints.only = T,
        ...
      ) {
@@ -195,9 +195,9 @@ ENAset = R6::R6Class("ENAset",
      #####
      ## Private Functions
      #####
-     run = function() {
-       # Reference for the ENAdata object
+     run = function() {       
        df = self$enadata$adjacency.vectors;
+
        ###
        # Backup of ENA data, this is not touched again.
        ###
@@ -212,7 +212,7 @@ ENAset = R6::R6Class("ENAset",
 
        ###
        # Normalize the raw data using self$function.params$norm.by,
-       # which defaults to calling rENA::dont_sphere_norm_c
+       # which defaults to calling rENA::.sphere_norm
        ###
        self$line.weights = self$function.params$norm.by(self$points.raw);
 
@@ -221,9 +221,11 @@ ENAset = R6::R6Class("ENAset",
        # co-occurence names and set as colnames for the self$line.weights
        ##
        codeNames_tri = svector_to_ut(self$enadata$codes);
+
        colnames(self$line.weights) = codeNames_tri;
        # set the rownames to that of the original ENAdata file object
        rownames(self$line.weights) = rownames(df);
+
        attr(self$line.weights, opts$UNIT_NAMES) = attr(df, opts$UNIT_NAMES) #df[, .SD, with=T, .SDcols=self$enadata$get("unitsBy")];
        ###
 
@@ -238,6 +240,7 @@ ENAset = R6::R6Class("ENAset",
        colnames(self$points.normed.centered) = codeNames_tri;
        rownames(self$points.normed.centered) = rownames(df);
        attr(self$points.normed.centered, opts$UNIT_NAMES) = attr(self$enadata$adjacency.vectors.raw, opts$UNIT_NAMES)
+
        ###
 
        ###
