@@ -24,8 +24,9 @@ ena.writeup <- function(
   comparison = NULL, comparison.groups = NULL, sig.dig = 2,
   output_dir = getwd(), type = c("file","stream"), theory = T, methods = T
 ) {
-  file = rmarkdown::render(system.file("rmd","methods.rmd", package="rENA"), output_dir = getwd(),
-                    knit_root_dir = getwd(), intermediates_dir = getwd())
+  type = match.arg(type, choices = c("file","stream"), several.ok = FALSE)
+  file = rmarkdown::render(system.file("rmd","methods.rmd", package="rENA"), output_dir = output_dir,
+                    knit_root_dir = output_dir, intermediates_dir = output_dir, quiet = TRUE)
   if(type == "file") file
   else readChar(file, file.info(file)$size)
 }
